# Supported Model Providers and Model Lists

## LLM Model Providers

### 1. OpenAI

**Provider**

- `openai`

**Supported Models:**

- `gpt-4.1`
- `gpt-4.1-mini`
- `gpt-4.1-nano`
- `gpt-4.5-preview`
- `gpt-4o`
- `gpt-4o-realtime-preview`
- `gpt-4o-mini`
- `o1`
- `o1-pro`
- `o1-mini`
- `o3`
- `o3-pro`
- `o3-mini`
- `o4-mini`

**Embedding Models:**

- `text-embedding-3-small`
- `text-embedding-3-large`
- `text-embedding-ada-002`

📚 **Reference Link:** <https://platform.openai.com/docs/pricing>

---

### 2. Anthropic Claude

**Provider**

- `anthropic`

**Supported Models:**

- `claude-opus-4-20250514`
- `claude-sonnet-4-20250514`
- `claude-3-7-sonnet-20250219`
- `claude-3-5-sonnet-20241022`
- `claude-3-5-haiku-20241022`

📚 **Reference Link:** <https://www.anthropic.com/api>

---

### 3. AWS Bedrock

**Provider**

- `bedrock`


**Supported Claude Models:**

- `Claude-Opus-4`
- `Claude-Sonnet-4`
- `Claude-Sonnet-3.7`
- `Claude-Sonnet-3.5`

📚 **Reference Link:** <https://aws.amazon.com/bedrock/>

---

### 4. Google Gemini

**Provider**

- `gemini`

**Supported Models:**

- `gemini-2.5-pro`
- `gemini-2.5-flash`
- `gemini-2.0-flash`
- `gemini-1.5-pro`
- `gemini-1.5-flash`

**Embedding Models:**

- `gemini-embedding-001`

📚 **Reference Link:** <https://ai.google.dev/gemini-api/docs/pricing>

---

### 5. Groq

**Provider**

- `groq`

**Supported Models:**

- `Kimi-K2-Instruct`
- `Llama-4-Scout-17B-16E-Instruct`
- `Llama-4-Maverick-17B-128E-Instruct`
- `Llama-Guard-4-12B`
- `DeepSeek-R1-Distill-Llama-70B`
- `Qwen3-32B`
- `Llama-3.3-70B-Instruct`

📚 **Reference Link:** <https://groq.com/pricing>

---

### 6. Monica (Proxy Platform)

**Provider**

- `monica`

**OpenAI Models:**

- `gpt-4.1`
- `gpt-4.1-mini`
- `gpt-4.1-nano`
- `gpt-4o-2024-11-20`
- `gpt-4o-mini-2024-07-18`
- `o4-mini`
- `o3`

**Anthropic Claude Models:**

- `claude-opus-4-20250514`
- `claude-sonnet-4-20250514`
- `claude-3-7-sonnet-latest`
- `claude-3-5-sonnet-20241022`
- `claude-3-5-sonnet-20240620`
- `claude-3-5-haiku-20241022`
- `claude-3-opus-20240229`
- `claude-3-haiku-20240307`

**Google Gemini Models:**

- `gemini-2.5-pro-preview-03-25`
- `gemini-2.5-flash-lite`
- `gemini-2.5-flash-preview-05-20`
- `gemini-2.0-flash-001`
- `gemini-1.5-pro-002`
- `gemini-1.5-flash-002`

**DeepSeek Models:**

- `deepseek-reasoner`
- `deepseek-chat`

**Meta Llama Models:**

- `llama-3-8b-instruct`
- `llama-3.1-8b-instruct`
- `llama-3.3-70b-instruct`
- `llama-3-70b-instruct`
- `llama-3.1-405b-instruct`

**xAI Grok Models:**

- `grok-3-beta`
- `grok-beta`

📚 **Reference Link:** <https://platform.monica.im/docs/en/models-and-pricing>

---

### 7. OpenRouter (Proxy Platform)

**Provider**

- `openrouter`

**OpenAI Models:**

- `openai/gpt-5`
- `openai/gpt-4.1`
- `openai/gpt-4.1-mini`
- `openai/o1`
- `openai/o1-pro`
- `openai/o1-mini`
- `openai/o3`
- `openai/o3-pro`
- `openai/o3-mini`
- `openai/o4-mini`

**xAI Grok Models:**

- `x-ai/grok-4`
- `x-ai/grok-3`
- `x-ai/grok-3-mini`

**Anthropic Claude Models:**

- `anthropic/claude-opus-4`
- `anthropic/claude-sonnet-4`

**Google Gemini Models:**

- `google/gemini-2.5-flash`
- `google/gemini-2.5-pro`

📚 **Reference Link:** <https://openrouter.ai/models>

---

### 8. Azure OpenAI

**Provider**

- `azure`


**Supported Models:**

- `gpt-4.1`
- `gpt-4.1-mini`
- `gpt-4.1-nano`
- `o1`
- `o3`
- `o4-mini`

📚 **Reference Link:** <https://azure.microsoft.com/en-us/pricing/details/cognitive-services/openai-service/>

---

### 9. DeepSeek

**Provider**

- `deepseek`

**Supported Models:**

- `deepseek-chat`
- `deepseek-reasoner`

📚 **Reference Link:** <https://platform.deepseek.com/>

---

### 10. Alibaba Cloud Qwen

**Supported Models:**

- `qwen-max-latest`
- `qwen-plus-latest`
- `qwen-turbo-latest`
- `qwen-vl-max-latest` (Grounding)
- `qwen-vl-plus-latest` (Grounding)

**Embedding Models:**

- `text-embedding-v4`
- `text-embedding-v3`

📚 **Reference Link:** <https://bailian.console.aliyun.com/?tab=doc#/doc/?type=model&url=https%3A%2F%2Fhelp.aliyun.com%2Fdocument_detail%2F2840914.html&renderType=iframe>

---

### 11. ByteDance Doubao

**Supported Models:**

- `doubao-seed-1-6-flash-250615`
- `doubao-seed-1-6-thinking-250715`
- `doubao-seed-1-6-250615`
- `doubao-1.5-vision-pro-250328` (Grounding)
- `doubao-1-5-thinking-vision-pro-250428` (Grounding)
- `doubao-1-5-ui-tars-250428` (Grounding)

**Embedding Models:**

- `doubao-embedding-large-text-250515`
- `doubao-embedding-text-240715`

📚 **Reference Link:** <https://console.volcengine.com/ark/region:ark+cn-beijing/model?vendor=Bytedance&view=LIST_VIEW>

---

### 12. Zhipu GLM

**Supported Models:**

- `GLM-4-Plus`
- `GLM-4-Air-250414`
- `GLM-4-AirX` (Grounding)
- `GLM-4V-Plus-0111` (Grounding)

**Embedding Models:**

- `Embedding-3`
- `Embedding-2`

📚 **Reference Link:** <https://open.bigmodel.cn/pricing>

---

### 13. SiliconFlow

**Supported Models:**

- `Kimi-K2-Instruct`
- `DeepSeek-V3`
- `DeepSeek-R1`
- `Qwen3-32B`

📚 **Reference Link:** <https://cloud.siliconflow.cn/sft-d1pi8rbk20jc73c62gm0/models>

---

## 🔤 Dedicated Embedding Providers

### 14. Jina AI

**Embedding Models:**

- `jina-embeddings-v4`
- `jina-embeddings-v3`

📚 **Reference Link:** <https://jina.ai/embeddings>

---

## 🔍 AI Search Engines

### 15. Bocha AI

**Service Type:** AI Research & Search

📚 **Reference Link:** <https://open.bochaai.com/overview>

---

### 16. Exa

**Service Type:** AI Research & Search

**Pricing Model:**

- $5.00 / 1k agent searches
- $5.00 / 1k exa-research agent page reads
- $10.00 / 1k exa-research-pro agent page reads
- $5.00 / 1M reasoning tokens

📚 **Reference Link:** <https://dashboard.exa.ai/home>
